strip_literal_suffix_at

Function strip_literal_suffix_at 

fn strip_literal_suffix_at(
    hir: &Hir,
    suffix: &[u8],
    suffix_cursor: usize,
) -> Option<(Hir, usize)>
Strip a terminal part of suffix[..suffix_cursor] from the end of hir.

The returned cursor marks the end of the part of suffix that remains to be stripped. Thus, this call removes suffix[after..suffix_cursor], where after is the returned cursor. A non-zero cursor may be returned only when the returned HIR cannot consume any bytes. This lets a concatenation continue stripping from its preceding child without losing adjacency.